kubewait
~~~~~~~~

Maintainer: Joe Black <joeblack949@gmail.com>
Repository: https://www.github.com/joeblackwaslike/kubewait

Description
-----------

This project is designed to be used to pause init as an init container until
required kubernetes apps/services are up and ready.  Names passed to kubewait
can be the names of Deployments or StatefulSets.
